@@ -2,7 +2,7 @@
 #
 #   fork.rb -
 #   	$Release Version: 0.9.6 $
-#   	$Revision: 56371 $
+#   	$Revision$
 #   	by Keiju ISHITSUKA(keiju@ruby-lang.org)
 #
 # --
@@ -16,12 +16,12 @@ module IRB
   module ExtendCommand
     class Fork < Nop
       def execute
-        pid = send ExtendCommand.irb_original_method_name("fork")
+        pid = __send__ ExtendCommand.irb_original_method_name("fork")
         unless pid
           class << self
             alias_method :exit, ExtendCommand.irb_original_method_name('exit')
           end
-          if iterator?
+          if block_given?
             begin
               yield
             ensure
@@ -35,5 +35,3 @@ module IRB
   end
 end
 # :startdoc:
-
-
