@@ -54,6 +54,7 @@ module IRB
         @use_multiline = nil
       end
       @use_colorize = IRB.conf[:USE_COLORIZE]
+      @use_autocomplete = IRB.conf[:USE_AUTOCOMPLETE]
       @verbose = IRB.conf[:VERBOSE]
       @io = nil
 
@@ -124,6 +125,8 @@ module IRB
       end
       self.save_history = IRB.conf[:SAVE_HISTORY] if IRB.conf[:SAVE_HISTORY]
 
+      @extra_doc_dirs = IRB.conf[:EXTRA_DOC_DIRS]
+
       @echo = IRB.conf[:ECHO]
       if @echo.nil?
         @echo = true
@@ -131,7 +134,7 @@ module IRB
 
       @echo_on_assignment = IRB.conf[:ECHO_ON_ASSIGNMENT]
       if @echo_on_assignment.nil?
-        @echo_on_assignment = false
+        @echo_on_assignment = :truncate
       end
 
       @newline_before_multiline_output = IRB.conf[:NEWLINE_BEFORE_MULTILINE_OUTPUT]
@@ -147,18 +150,18 @@ module IRB
 
     # The toplevel workspace, see #home_workspace
     attr_reader :workspace_home
-    # WorkSpace in the current context
+    # WorkSpace in the current context.
     attr_accessor :workspace
-    # The current thread in this context
+    # The current thread in this context.
     attr_reader :thread
-    # The current input method
+    # The current input method.
     #
     # Can be either StdioInputMethod, ReadlineInputMethod,
     # ReidlineInputMethod, FileInputMethod or other specified when the
     # context is created. See ::new for more # information on +input_method+.
     attr_accessor :io
 
-    # Current irb session
+    # Current irb session.
     attr_accessor :irb
     # A copy of the default <code>IRB.conf[:AP_NAME]</code>
     attr_accessor :ap_name
@@ -185,20 +188,22 @@ module IRB
     #
     # A copy of the default <code>IRB.conf[:USE_COLORIZE]</code>
     attr_reader :use_colorize
+    # A copy of the default <code>IRB.conf[:USE_AUTOCOMPLETE]</code>
+    attr_reader :use_autocomplete
     # A copy of the default <code>IRB.conf[:INSPECT_MODE]</code>
     attr_reader :inspect_mode
 
     # A copy of the default <code>IRB.conf[:PROMPT_MODE]</code>
     attr_reader :prompt_mode
-    # Standard IRB prompt
+    # Standard IRB prompt.
     #
     # See IRB@Customizing+the+IRB+Prompt for more information.
     attr_accessor :prompt_i
-    # IRB prompt for continuated strings
+    # IRB prompt for continuated strings.
     #
     # See IRB@Customizing+the+IRB+Prompt for more information.
     attr_accessor :prompt_s
-    # IRB prompt for continuated statement (e.g. immediately after an +if+)
+    # IRB prompt for continuated statement. (e.g. immediately after an +if+)
     #
     # See IRB@Customizing+the+IRB+Prompt for more information.
     attr_accessor :prompt_c
@@ -238,9 +243,12 @@ module IRB
     #
     # If set to +false+, <code>^D</code> will quit irb.
     attr_accessor :ignore_eof
+    # Specify the installation locations of the ri file to be displayed in the
+    # document dialog.
+    attr_accessor :extra_doc_dirs
     # Whether to echo the return value to output or not.
     #
-    # Uses IRB.conf[:ECHO] if available, or defaults to +true+.
+    # Uses <code>IRB.conf[:ECHO]</code> if available, or defaults to +true+.
     #
     #     puts "hello"
     #     # hello
@@ -249,18 +257,44 @@ module IRB
     #     puts "omg"
     #     # omg
     attr_accessor :echo
-    # Whether to echo for assignment expressions
+    # Whether to echo for assignment expressions.
     #
-    # Uses IRB.conf[:ECHO_ON_ASSIGNMENT] if available, or defaults to +false+.
+    # If set to +false+, the value of assignment will not be shown.
+    #
+    # If set to +true+, the value of assignment will be shown.
+    #
+    # If set to +:truncate+, the value of assignment will be shown and truncated.
+    #
+    # It defaults to +:truncate+.
     #
-    #     a = "omg"
-    #     IRB.CurrentContext.echo_on_assignment = true
     #     a = "omg"
     #     #=> omg
+    #
+    #     a = "omg" * 10
+    #     #=> omgomgomgomgomgomgomg...
+    #
+    #     IRB.CurrentContext.echo_on_assignment = false
+    #     a = "omg"
+    #
+    #     IRB.CurrentContext.echo_on_assignment = true
+    #     a = "omg" * 10
+    #     #=> omgomgomgomgomgomgomgomgomgomg
+    #
+    # To set the behaviour of showing on assignment in irb:
+    #
+    #     IRB.conf[:ECHO_ON_ASSIGNMENT] = :truncate or true or false
+    #
+    # or
+    #
+    #     irb_context.echo_on_assignment = :truncate or true or false
+    #
+    # or
+    #
+    #     IRB.CurrentContext.echo_on_assignment = :truncate or true or false
     attr_accessor :echo_on_assignment
     # Whether a newline is put before multiline output.
     #
-    # Uses IRB.conf[:NEWLINE_BEFORE_MULTILINE_OUTPUT] if available,
+    # Uses <code>IRB.conf[:NEWLINE_BEFORE_MULTILINE_OUTPUT]</code> if available,
     # or defaults to +true+.
     #
     #     "abc\ndef"
@@ -300,6 +334,8 @@ module IRB
     alias use_readline? use_singleline
     # Alias for #use_colorize
     alias use_colorize? use_colorize
+    # Alias for #use_autocomplete
+    alias use_autocomplete? use_autocomplete
     # Alias for #rc
     alias rc? rc
     alias ignore_sigint? ignore_sigint
@@ -355,6 +391,7 @@ module IRB
       @prompt_c = pconf[:PROMPT_C]
       @prompt_n = pconf[:PROMPT_N]
       @return_format = pconf[:RETURN]
+      @return_format = "%s\n" if @return_format == nil
       if ai = pconf.include?(:AUTO_INDENT)
         @auto_indent_mode = ai
       else
@@ -447,6 +484,8 @@ module IRB
     # Exits the current session, see IRB.irb_exit
     def exit(ret = 0)
       IRB.irb_exit(@irb, ret)
+    rescue UncaughtThrowError
+      super
     end
 
     NOPRINTING_IVARS = ["@last_value"] # :nodoc:
