@@ -20,7 +20,7 @@
 # See Net::HTTP for an overview and examples.
 #
 
-require_relative 'protocol'
+require 'net/protocol'
 require 'uri'
 autoload :OpenSSL, 'openssl'
 
@@ -35,7 +35,7 @@ module Net   #:nodoc:
   #
   # Net::HTTP provides a rich library which can be used to build HTTP
   # user-agents.  For more details about HTTP see
-  # [RFC2616](http://www.ietf.org/rfc/rfc2616.txt)
+  # [RFC2616](http://www.ietf.org/rfc/rfc2616.txt).
   #
   # Net::HTTP is designed to work closely with URI.  URI::HTTP#host,
   # URI::HTTP#port and URI::HTTP#request_uri are designed to work with
@@ -87,7 +87,7 @@ module Net   #:nodoc:
   #
   # == How to use Net::HTTP
   #
-  # The following example code can be used as the basis of a HTTP user-agent
+  # The following example code can be used as the basis of an HTTP user-agent
   # which can perform a variety of request types using persistent
   # connections.
   #
@@ -104,14 +104,13 @@ module Net   #:nodoc:
   # open for multiple requests in the block if the server indicates it
   # supports persistent connections.
   #
+  # If you wish to re-use a connection across multiple HTTP requests without
+  # automatically closing it you can use ::new and then call #start and
+  # #finish manually.
+  #
   # The request types Net::HTTP supports are listed below in the section "HTTP
   # Request Classes".
   #
-  # If you wish to re-use a connection across multiple HTTP requests without
-  # automatically closing it you can use ::new instead of ::start.  #request
-  # will automatically open a connection to the server if one is not currently
-  # open.  You can manually close the connection with #finish.
-  #
   # For all the Net::HTTP request objects and shortcut request methods you may
   # supply either a String for the request path or a URI from which Net::HTTP
   # will extract the request path.
@@ -170,7 +169,7 @@ module Net   #:nodoc:
   # === POST
   #
   # A POST can be made using the Net::HTTP::Post request class.  This example
-  # creates a urlencoded POST body:
+  # creates a URL encoded POST body:
   #
   #   uri = URI('http://www.example.com/todo.cgi')
   #   req = Net::HTTP::Post.new(uri)
@@ -187,13 +186,10 @@ module Net   #:nodoc:
   #     res.value
   #   end
   #
-  # At this time Net::HTTP does not support multipart/form-data.  To send
-  # multipart/form-data use Net::HTTPRequest#body= and
-  # Net::HTTPRequest#content_type=:
+  # To send multipart/form-data use Net::HTTPHeader#set_form:
   #
   #   req = Net::HTTP::Post.new(uri)
-  #   req.body = multipart_data
-  #   req.content_type = 'multipart/form-data'
+  #   req.set_form([['upload', File.open('foo.bar')]], 'multipart/form-data')
   #
   # Other requests that can contain a body such as PUT can be created in the
   # same way using the corresponding request class (Net::HTTP::Put).
@@ -222,7 +218,7 @@ module Net   #:nodoc:
   # === Basic Authentication
   #
   # Basic authentication is performed according to
-  # [RFC2617](http://www.ietf.org/rfc/rfc2617.txt)
+  # [RFC2617](http://www.ietf.org/rfc/rfc2617.txt).
   #
   #   uri = URI('http://example.com/index.html?key=value')
   #
@@ -266,7 +262,7 @@ module Net   #:nodoc:
   #   end
   #
   # Or if you simply want to make a GET request, you may pass in an URI
-  # object that has a HTTPS URL. Net::HTTP automatically turn on TLS
+  # object that has an HTTPS URL. Net::HTTP automatically turns on TLS
   # verification if the URI object has a 'https' URI scheme.
   #
   #   uri = URI('https://example.com/')
@@ -331,6 +327,8 @@ module Net   #:nodoc:
   # HTTPInformation::                    1xx
   #   HTTPContinue::                        100
   #   HTTPSwitchProtocol::                  101
+  #   HTTPProcessing::                      102
+  #   HTTPEarlyHints::                      103
   # HTTPSuccess::                        2xx
   #   HTTPOK::                              200
   #   HTTPCreated::                         201
@@ -340,6 +338,7 @@ module Net   #:nodoc:
   #   HTTPResetContent::                    205
   #   HTTPPartialContent::                  206
   #   HTTPMultiStatus::                     207
+  #   HTTPAlreadyReported::                 208
   #   HTTPIMUsed::                          226
   # HTTPRedirection::                    3xx
   #   HTTPMultipleChoices::                 300
@@ -349,6 +348,7 @@ module Net   #:nodoc:
   #   HTTPNotModified::                     304
   #   HTTPUseProxy::                        305
   #   HTTPTemporaryRedirect::               307
+  #   HTTPPermanentRedirect::               308
   # HTTPClientError::                    4xx
   #   HTTPBadRequest::                      400
   #   HTTPUnauthorized::                    401
@@ -368,6 +368,7 @@ module Net   #:nodoc:
   #   HTTPUnsupportedMediaType::            415
   #   HTTPRequestedRangeNotSatisfiable::    416
   #   HTTPExpectationFailed::               417
+  #   HTTPMisdirectedRequest::              421
   #   HTTPUnprocessableEntity::             422
   #   HTTPLocked::                          423
   #   HTTPFailedDependency::                424
@@ -383,7 +384,10 @@ module Net   #:nodoc:
   #   HTTPServiceUnavailable::              503
   #   HTTPGatewayTimeOut::                  504
   #   HTTPVersionNotSupported::             505
+  #   HTTPVariantAlsoNegotiates::           506
   #   HTTPInsufficientStorage::             507
+  #   HTTPLoopDetected::                    508
+  #   HTTPNotExtended::                     510
   #   HTTPNetworkAuthenticationRequired::   511
   #
   # There is also the Net::HTTPBadResponse exception which is raised when
@@ -392,11 +396,11 @@ module Net   #:nodoc:
   class HTTP < Protocol
 
     # :stopdoc:
-    Revision = %q$Revision: 67237 $.split[1]
+    VERSION = "0.2.0"
+    Revision = %q$Revision$.split[1]
     HTTPVersion = '1.1'
     begin
       require 'zlib'
-      require 'stringio'  #for our purposes (unpacking gzip) lump these together
       HAVE_ZLIB=true
     rescue LoadError
       HAVE_ZLIB=false
@@ -431,7 +435,7 @@ module Net   #:nodoc:
     #
     # Gets the body text from the target and outputs it to $stdout.  The
     # target can either be specified as
-    # (+uri+), or as (+host+, +path+, +port+ = 80); so:
+    # (+uri+, +headers+), or as (+host+, +path+, +port+ = 80); so:
     #
     #    Net::HTTP.get_print URI('http://www.example.com/index.html')
     #
@@ -439,8 +443,12 @@ module Net   #:nodoc:
     #
     #    Net::HTTP.get_print 'www.example.com', '/index.html'
     #
-    def HTTP.get_print(uri_or_host, path = nil, port = nil)
-      get_response(uri_or_host, path, port) {|res|
+    # you can also specify request headers:
+    #
+    #    Net::HTTP.get_print URI('http://www.example.com/index.html'), { 'Accept' => 'text/html' }
+    #
+    def HTTP.get_print(uri_or_host, path_or_headers = nil, port = nil)
+      get_response(uri_or_host, path_or_headers, port) {|res|
         res.read_body do |chunk|
           $stdout.print chunk
         end
@@ -450,7 +458,7 @@ module Net   #:nodoc:
 
     # Sends a GET request to the target and returns the HTTP response
     # as a string.  The target can either be specified as
-    # (+uri+), or as (+host+, +path+, +port+ = 80); so:
+    # (+uri+, +headers+), or as (+host+, +path+, +port+ = 80); so:
     #
     #    print Net::HTTP.get(URI('http://www.example.com/index.html'))
     #
@@ -458,13 +466,17 @@ module Net   #:nodoc:
     #
     #    print Net::HTTP.get('www.example.com', '/index.html')
     #
-    def HTTP.get(uri_or_host, path = nil, port = nil)
-      get_response(uri_or_host, path, port).body
+    # you can also specify request headers:
+    #
+    #    Net::HTTP.get(URI('http://www.example.com/index.html'), { 'Accept' => 'text/html' })
+    #
+    def HTTP.get(uri_or_host, path_or_headers = nil, port = nil)
+      get_response(uri_or_host, path_or_headers, port).body
     end
 
     # Sends a GET request to the target and returns the HTTP response
     # as a Net::HTTPResponse object.  The target can either be specified as
-    # (+uri+), or as (+host+, +path+, +port+ = 80); so:
+    # (+uri+, +headers+), or as (+host+, +path+, +port+ = 80); so:
     #
     #    res = Net::HTTP.get_response(URI('http://www.example.com/index.html'))
     #    print res.body
@@ -474,17 +486,23 @@ module Net   #:nodoc:
     #    res = Net::HTTP.get_response('www.example.com', '/index.html')
     #    print res.body
     #
-    def HTTP.get_response(uri_or_host, path = nil, port = nil, &block)
-      if path
+    # you can also specify request headers:
+    #
+    #    Net::HTTP.get_response(URI('http://www.example.com/index.html'), { 'Accept' => 'text/html' })
+    #
+    def HTTP.get_response(uri_or_host, path_or_headers = nil, port = nil, &block)
+      if path_or_headers && !path_or_headers.is_a?(Hash)
         host = uri_or_host
+        path = path_or_headers
         new(host, port || HTTP.default_port).start {|http|
           return http.request_get(path, &block)
         }
       else
         uri = uri_or_host
+        headers = path_or_headers
         start(uri.hostname, uri.port,
               :use_ssl => uri.scheme == 'https') {|http|
-          return http.request_get(uri, &block)
+          return http.request_get(uri, headers, &block)
         }
       end
     end
@@ -513,14 +531,13 @@ module Net   #:nodoc:
     #
     #   { "cmd" => "search", "q" => "ruby", "max" => "50" }
     #
-    # This method also does Basic Authentication iff +url+.user exists.
+    # This method also does Basic Authentication if and only if +url+.user exists.
     # But userinfo for authentication is deprecated (RFC3986).
     # So this feature will be removed.
     #
     # Example:
     #
     #   require 'net/http'
-    #   require 'uri'
     #
     #   Net::HTTP.post_form URI('http://www.example.com/search.cgi'),
     #                       { "q" => "ruby", "max" => "50" }
@@ -575,8 +592,8 @@ module Net   #:nodoc:
     # _opt_     :: optional hash
     #
     # _opt_ sets following values by its accessor.
-    # The keys are ca_file, ca_path, cert, cert_store, ciphers,
-    # close_on_empty_response, key, open_timeout, read_timeout, ssl_timeout,
+    # The keys are ipaddr, ca_file, ca_path, cert, cert_store, ciphers, keep_alive_timeout,
+    # close_on_empty_response, key, open_timeout, read_timeout, write_timeout, ssl_timeout,
     # ssl_version, use_ssl, verify_callback, verify_depth and verify_mode.
     # If you set :use_ssl as true, you can use https and default value of
     # verify_mode is set as OpenSSL::SSL::VERIFY_PEER.
@@ -594,6 +611,7 @@ module Net   #:nodoc:
       p_addr = :ENV if arg.size < 2
       port = https_default_port if !port && opt && opt[:use_ssl]
       http = new(address, port, p_addr, p_port, p_user, p_pass)
+      http.ipaddr = opt[:ipaddr] if opt && opt[:ipaddr]
 
       if opt
         if opt[:use_ssl]
@@ -664,6 +682,7 @@ module Net   #:nodoc:
     def initialize(address, port = nil)
       @address = address
       @port    = (port || HTTP.default_port)
+      @ipaddr = nil
       @local_host = nil
       @local_port = nil
       @curr_http_version = HTTPVersion
@@ -674,6 +693,7 @@ module Net   #:nodoc:
       @started = false
       @open_timeout = 60
       @read_timeout = 60
+      @write_timeout = 60
       @continue_timeout = nil
       @max_retries = 1
       @debug_output = nil
@@ -730,6 +750,17 @@ module Net   #:nodoc:
     attr_writer :proxy_user
     attr_writer :proxy_pass
 
+    # The IP address to connect to/used to connect to
+    def ipaddr
+      started? ?  @socket.io.peeraddr[3] : @ipaddr
+    end
+
+    # Set the IP address to connect to
+    def ipaddr=(addr)
+      raise IOError, "ipaddr value changed, but session already started" if started?
+      @ipaddr = addr
+    end
+
     # Number of seconds to wait for the connection to open. Any number
     # may be used, including Floats for fractional seconds. If the HTTP
     # object cannot open a connection in this many seconds, it raises a
@@ -742,6 +773,13 @@ module Net   #:nodoc:
     # it raises a Net::ReadTimeout exception. The default value is 60 seconds.
     attr_reader :read_timeout
 
+    # Number of seconds to wait for one block to be written (via one write(2)
+    # call). Any number may be used, including Floats for fractional
+    # seconds. If the HTTP object cannot write data in this many seconds,
+    # it raises a Net::WriteTimeout exception. The default value is 60 seconds.
+    # Net::WriteTimeout is not raised on Windows.
+    attr_reader :write_timeout
+
     # Maximum number of times to retry an idempotent request in case of
     # Net::ReadTimeout, IOError, EOFError, Errno::ECONNRESET,
     # Errno::ECONNABORTED, Errno::EPIPE, OpenSSL::SSL::SSLError,
@@ -764,6 +802,12 @@ module Net   #:nodoc:
       @read_timeout = sec
     end
 
+    # Setter for the write_timeout attribute.
+    def write_timeout=(sec)
+      @socket.write_timeout = sec if @socket
+      @write_timeout = sec
+    end
+
     # Seconds to wait for 100 Continue response. If the HTTP object does not
     # receive a response in this many seconds it sends the request body. The
     # default value is +nil+.
@@ -813,6 +857,7 @@ module Net   #:nodoc:
       :@cert,
       :@cert_store,
       :@ciphers,
+      :@extra_chain_cert,
       :@key,
       :@ssl_timeout,
       :@ssl_version,
@@ -821,6 +866,7 @@ module Net   #:nodoc:
       :@verify_callback,
       :@verify_depth,
       :@verify_mode,
+      :@verify_hostname,
     ]
     SSL_ATTRIBUTES = [
       :ca_file,
@@ -828,6 +874,7 @@ module Net   #:nodoc:
       :cert,
       :cert_store,
       :ciphers,
+      :extra_chain_cert,
       :key,
       :ssl_timeout,
       :ssl_version,
@@ -836,6 +883,7 @@ module Net   #:nodoc:
       :verify_callback,
       :verify_depth,
       :verify_mode,
+      :verify_hostname,
     ]
 
     # Sets path of a CA certification file in PEM format.
@@ -857,6 +905,10 @@ module Net   #:nodoc:
     # Sets the available ciphers.  See OpenSSL::SSL::SSLContext#ciphers=
     attr_accessor :ciphers
 
+    # Sets the extra X509 certificates to be added to the certificate chain.
+    # See OpenSSL::SSL::SSLContext#extra_chain_cert=
+    attr_accessor :extra_chain_cert
+
     # Sets an OpenSSL::PKey::RSA or OpenSSL::PKey::DSA object.
     # (This method is appeared in Michal Rokos's OpenSSL extension.)
     attr_accessor :key
@@ -885,6 +937,10 @@ module Net   #:nodoc:
     # OpenSSL::SSL::VERIFY_NONE or OpenSSL::SSL::VERIFY_PEER are acceptable.
     attr_accessor :verify_mode
 
+    # Sets to check the server certificate is valid for the hostname.
+    # See OpenSSL::SSL::SSLContext#verify_hostname=
+    attr_accessor :verify_hostname
+
     # Returns the X.509 certificates the server presented.
     def peer_cert
       if not use_ssl? or not @socket
@@ -923,31 +979,37 @@ module Net   #:nodoc:
     private :do_start
 
     def connect
-      if proxy? then
-        conn_address = proxy_address
-        conn_port    = proxy_port
-      else
-        conn_address = address
-        conn_port    = port
+      if use_ssl?
+        # reference early to load OpenSSL before connecting,
+        # as OpenSSL may take time to load.
+        @ssl_context = OpenSSL::SSL::SSLContext.new
       end
 
-      D "opening connection to #{conn_address}:#{conn_port}..."
-      s = Timeout.timeout(@open_timeout, Net::OpenTimeout) {
-        begin
-          TCPSocket.open(conn_address, conn_port, @local_host, @local_port)
-        rescue => e
-          raise e, "Failed to open TCP connection to " +
-            "#{conn_address}:#{conn_port} (#{e.message})"
-        end
-      }
+      if proxy? then
+        conn_addr = proxy_address
+        conn_port = proxy_port
+      else
+        conn_addr = conn_address
+        conn_port = port
+      end
+
+      D "opening connection to #{conn_addr}:#{conn_port}..."
+      begin
+        s = Socket.tcp conn_addr, conn_port, @local_host, @local_port, connect_timeout: @open_timeout
+      rescue => e
+        e = Net::OpenTimeout.new(e) if e.is_a?(Errno::ETIMEDOUT) #for compatibility with previous versions
+        raise e, "Failed to open TCP connection to " +
+          "#{conn_addr}:#{conn_port} (#{e.message})"
+      end
       s.setsockopt(Socket::IPPROTO_TCP, Socket::TCP_NODELAY, 1)
       D "opened"
       if use_ssl?
         if proxy?
           plain_sock = BufferedIO.new(s, read_timeout: @read_timeout,
+                                      write_timeout: @write_timeout,
                                       continue_timeout: @continue_timeout,
                                       debug_output: @debug_output)
-          buf = "CONNECT #{@address}:#{@port} HTTP/#{HTTPVersion}\r\n"
+          buf = "CONNECT #{conn_address}:#{@port} HTTP/#{HTTPVersion}\r\n"
           buf << "Host: #{@address}:#{@port}\r\n"
           if proxy_user
             credential = ["#{proxy_user}:#{proxy_pass}"].pack('m0')
@@ -962,18 +1024,19 @@ module Net   #:nodoc:
         ssl_parameters = Hash.new
         iv_list = instance_variables
         SSL_IVNAMES.each_with_index do |ivname, i|
-          if iv_list.include?(ivname) and
+          if iv_list.include?(ivname)
             value = instance_variable_get(ivname)
-            ssl_parameters[SSL_ATTRIBUTES[i]] = value if value
+            unless value.nil?
+              ssl_parameters[SSL_ATTRIBUTES[i]] = value
+            end
           end
         end
-        @ssl_context = OpenSSL::SSL::SSLContext.new
         @ssl_context.set_params(ssl_parameters)
         @ssl_context.session_cache_mode =
           OpenSSL::SSL::SSLContext::SESSION_CACHE_CLIENT |
           OpenSSL::SSL::SSLContext::SESSION_CACHE_NO_INTERNAL_STORE
         @ssl_context.session_new_cb = proc {|sock, sess| @ssl_session = sess }
-        D "starting SSL for #{conn_address}:#{conn_port}..."
+        D "starting SSL for #{conn_addr}:#{conn_port}..."
         s = OpenSSL::SSL::SSLSocket.new(s, @ssl_context)
         s.sync_close = true
         # Server Name Indication (SNI) RFC 3546
@@ -983,14 +1046,16 @@ module Net   #:nodoc:
           s.session = @ssl_session
         end
         ssl_socket_connect(s, @open_timeout)
-        if @ssl_context.verify_mode != OpenSSL::SSL::VERIFY_NONE
+        if (@ssl_context.verify_mode != OpenSSL::SSL::VERIFY_NONE) && @ssl_context.verify_hostname
           s.post_connection_check(@address)
         end
-        D "SSL established"
+        D "SSL established, protocol: #{s.ssl_version}, cipher: #{s.cipher[0]}"
       end
       @socket = BufferedIO.new(s, read_timeout: @read_timeout,
+                               write_timeout: @write_timeout,
                                continue_timeout: @continue_timeout,
                                debug_output: @debug_output)
+      @last_communicated = nil
       on_connect
     rescue => exception
       if s
@@ -1126,7 +1191,8 @@ module Net   #:nodoc:
     # The username of the proxy server, if one is configured.
     def proxy_user
       if ENVIRONMENT_VARIABLE_IS_MULTIUSER_SAFE && @proxy_from_env
-        proxy_uri&.user
+        user = proxy_uri&.user
+        unescape(user) if user
       else
         @proxy_user
       end
@@ -1135,7 +1201,8 @@ module Net   #:nodoc:
     # The password of the proxy server, if one is configured.
     def proxy_pass
       if ENVIRONMENT_VARIABLE_IS_MULTIUSER_SAFE && @proxy_from_env
-        proxy_uri&.password
+        pass = proxy_uri&.password
+        unescape(pass) if pass
       else
         @proxy_pass
       end
@@ -1146,10 +1213,15 @@ module Net   #:nodoc:
 
     private
 
+    def unescape(value)
+      require 'cgi/util'
+      CGI.unescape(value)
+    end
+
     # without proxy, obsolete
 
     def conn_address # :nodoc:
-      address()
+      @ipaddr || address()
     end
 
     def conn_port # :nodoc:
@@ -1492,7 +1564,13 @@ module Net   #:nodoc:
       begin
         begin_transport req
         res = catch(:response) {
-          req.exec @socket, @curr_http_version, edit_path(req.path)
+          begin
+            req.exec @socket, @curr_http_version, edit_path(req.path)
+          rescue Errno::EPIPE
+            # Failure when writing full request, but we can probably
+            # still read the received response.
+          end
+
           begin
             res = HTTPResponse.read_new(@socket)
             res.decode_content = req.decode_content
@@ -1508,7 +1586,7 @@ module Net   #:nodoc:
       rescue Net::OpenTimeout
         raise
       rescue Net::ReadTimeout, IOError, EOFError,
-             Errno::ECONNRESET, Errno::ECONNABORTED, Errno::EPIPE,
+             Errno::ECONNRESET, Errno::ECONNABORTED, Errno::EPIPE, Errno::ETIMEDOUT,
              # avoid a dependency on OpenSSL
              defined?(OpenSSL::SSL) ? OpenSSL::SSL::SSLError : IOError,
              Timeout::Error => exception
