@@ -10,7 +10,7 @@
 
 module RbConfig
   RUBY_VERSION.start_with?("3.1.") or
-    raise "ruby lib version (3.1.1) doesn't match executable version (#{RUBY_VERSION})"
+    raise "ruby lib version (3.1.2) doesn't match executable version (#{RUBY_VERSION})"
 
   # Ruby installed directory.
   TOPDIR = File.dirname(__FILE__).chomp!("/lib/ruby/3.1/powerpc64-openbsd")
@@ -21,9 +21,9 @@ module RbConfig
   CONFIG["DESTDIR"] = DESTDIR
   CONFIG["MAJOR"] = "3"
   CONFIG["MINOR"] = "1"
-  CONFIG["TEENY"] = "1"
-  CONFIG["PATCHLEVEL"] = "18"
-  CONFIG["INSTALL"] = '/usr/ports/pobj/ruby-3.1.1/bin/install -c'
+  CONFIG["TEENY"] = "2"
+  CONFIG["PATCHLEVEL"] = "20"
+  CONFIG["INSTALL"] = '/usr/ports/pobj/ruby-3.1.2/bin/install -c'
   CONFIG["EXEEXT"] = ""
   CONFIG["prefix"] = (TOPDIR || DESTDIR + "/usr/local")
   CONFIG["ruby_install_name"] = "$(RUBY_BASE_NAME)31"
@@ -147,9 +147,9 @@ module RbConfig
   CONFIG["DOT"] = ""
   CONFIG["MAKEDIRS"] = "mkdir -p"
   CONFIG["MKDIR_P"] = "mkdir -p"
-  CONFIG["INSTALL_DATA"] = "/usr/ports/pobj/ruby-3.1.1/bin/install -c -m 644"
-  CONFIG["INSTALL_SCRIPT"] = "/usr/ports/pobj/ruby-3.1.1/bin/install -c -m 755"
-  CONFIG["INSTALL_PROGRAM"] = "/usr/ports/pobj/ruby-3.1.1/bin/install -c -s -m 755"
+  CONFIG["INSTALL_DATA"] = "/usr/ports/pobj/ruby-3.1.2/bin/install -c -m 644"
+  CONFIG["INSTALL_SCRIPT"] = "/usr/ports/pobj/ruby-3.1.2/bin/install -c -m 755"
+  CONFIG["INSTALL_PROGRAM"] = "/usr/ports/pobj/ruby-3.1.2/bin/install -c -s -m 755"
   CONFIG["SET_MAKE"] = ""
   CONFIG["LN_S"] = "ln -s"
   CONFIG["DLLWRAP"] = ""
@@ -157,7 +157,7 @@ module RbConfig
   CONFIG["ASFLAGS"] = ""
   CONFIG["ARFLAGS"] = "rcD "
   CONFIG["try_header"] = ""
-  CONFIG["CC_VERSION_MESSAGE"] = "OpenBSD clang version 13.0.0\nTarget: powerpc64-unknown-openbsd7.1\nThread model: posix\nInstalledDir: /usr/bin"
+  CONFIG["CC_VERSION_MESSAGE"] = "OpenBSD clang version 13.0.0\nTarget: powerpc64-unknown-openbsd7.2\nThread model: posix\nInstalledDir: /usr/bin"
   CONFIG["CC_VERSION"] = "$(CC) --version"
   CONFIG["MJIT_CC"] = "/usr/bin/cc"
   CONFIG["CSRCFLAG"] = ""
@@ -181,21 +181,21 @@ module RbConfig
   CONFIG["NM"] = "nm"
   CONFIG["LD"] = "ld"
   CONFIG["CXX"] = "c++"
-  CONFIG["AS"] = "gas"
+  CONFIG["AS"] = ""
   CONFIG["AR"] = "ar"
   CONFIG["CC"] = "cc"
-  CONFIG["target_os"] = "openbsd7.1"
+  CONFIG["target_os"] = "openbsd7.2"
   CONFIG["target_vendor"] = "unknown"
   CONFIG["target_cpu"] = "powerpc64"
-  CONFIG["target"] = "powerpc64-unknown-openbsd7.1"
-  CONFIG["host_os"] = "openbsd7.1"
+  CONFIG["target"] = "powerpc64-unknown-openbsd7.2"
+  CONFIG["host_os"] = "openbsd7.2"
   CONFIG["host_vendor"] = "unknown"
   CONFIG["host_cpu"] = "powerpc64"
-  CONFIG["host"] = "powerpc64-unknown-openbsd7.1"
-  CONFIG["build_os"] = "openbsd7.1"
+  CONFIG["host"] = "powerpc64-unknown-openbsd7.2"
+  CONFIG["build_os"] = "openbsd7.2"
   CONFIG["build_vendor"] = "unknown"
   CONFIG["build_cpu"] = "powerpc64"
-  CONFIG["build"] = "powerpc64-unknown-openbsd7.1"
+  CONFIG["build"] = "powerpc64-unknown-openbsd7.2"
   CONFIG["RUBY_VERSION_NAME"] = "$(RUBY_BASE_NAME)-$(ruby_version)"
   CONFIG["RUBYW_BASE_NAME"] = "rubyw"
   CONFIG["RUBY_BASE_NAME"] = "ruby"
