@@ -1,7 +1,7 @@
-# frozen_string_literal: false
-require 'psych/tree_builder'
-require 'psych/scalar_scanner'
-require 'psych/class_loader'
+# frozen_string_literal: true
+require_relative '../tree_builder'
+require_relative '../scalar_scanner'
+require_relative '../class_loader'
 
 module Psych
   module Visitors
@@ -53,15 +53,6 @@ module Psych
         new(emitter, ss, options)
       end
 
-      def self.new emitter = nil, ss = nil, options = nil
-        return super if emitter && ss && options
-
-        if $VERBOSE
-          warn "This API is deprecated, please pass an emitter, scalar scanner, and options or call #{self}.create() (#{caller.first})"
-        end
-        create emitter, ss
-      end
-
       def initialize emitter, ss, options
         super()
         @started    = false
@@ -89,7 +80,7 @@ module Psych
           raise(TypeError, "Can't dump #{target.class}") unless method
 
           h[klass] = method
-        end
+        end.compare_by_identity
       end
 
       def start encoding = Nodes::Stream::UTF8
@@ -139,24 +130,6 @@ module Psych
           return @emitter.alias anchor
         end
 
-        if target.respond_to?(:to_yaml)
-          begin
-            loc = target.method(:to_yaml).source_location.first
-            if loc !~ /(syck\/rubytypes.rb|psych\/core_ext.rb)/
-              unless target.respond_to?(:encode_with)
-                if $VERBOSE
-                  warn "implementing to_yaml is deprecated, please implement \"encode_with\""
-                end
-
-                target.to_yaml(:nodump => true)
-              end
-            end
-          rescue
-            # public_method or source_location might be overridden,
-            # and it's OK to skip it since it's only to emit a warning
-          end
-        end
-
         if target.respond_to?(:encode_with)
           dump_coder target
         else
@@ -191,6 +164,8 @@ module Psych
         @emitter.end_mapping
       end
 
+      alias :visit_Delegator :visit_Object
+
       def visit_Struct o
         tag = ['!ruby/struct', o.class.name].compact.join(':')
 
@@ -206,41 +181,11 @@ module Psych
       end
 
       def visit_Exception o
-        tag = ['!ruby/exception', o.class.name].join ':'
-
-        @emitter.start_mapping nil, tag, false, Nodes::Mapping::BLOCK
-
-        {
-          'message'   => private_iv_get(o, 'mesg'),
-          'backtrace' => private_iv_get(o, 'backtrace'),
-        }.each do |k,v|
-          next unless v
-          @emitter.scalar k, nil, nil, true, false, Nodes::Scalar::ANY
-          accept v
-        end
-
-        dump_ivars o
-
-        @emitter.end_mapping
+        dump_exception o, o.message.to_s
       end
 
       def visit_NameError o
-        tag = ['!ruby/exception', o.class.name].join ':'
-
-        @emitter.start_mapping nil, tag, false, Nodes::Mapping::BLOCK
-
-        {
-          'message'   => o.message.to_s,
-          'backtrace' => private_iv_get(o, 'backtrace'),
-        }.each do |k,v|
-          next unless v
-          @emitter.scalar k, nil, nil, true, false, Nodes::Scalar::ANY
-          accept v
-        end
-
-        dump_ivars o
-
-        @emitter.end_mapping
+        dump_exception o, o.message.to_s
       end
 
       def visit_Regexp o
@@ -327,6 +272,8 @@ module Psych
           tag   = 'tag:yaml.org,2002:str'
           plain = false
           quote = false
+        elsif o == 'y' || o == 'n'
+          style = Nodes::Scalar::DOUBLE_QUOTED
         elsif @line_width && o.length > @line_width
           style = Nodes::Scalar::FOLDED
         elsif o =~ /^[^[:word:]][^"]*$/
@@ -336,7 +283,7 @@ module Psych
         end
 
         is_primitive = o.class == ::String
-        ivars = find_ivars o, is_primitive
+        ivars = is_primitive ? [] : o.instance_variables
 
         if ivars.empty?
           unless is_primitive
@@ -346,7 +293,7 @@ module Psych
           end
           @emitter.scalar o, nil, tag, plain, quote, style
         else
-          maptag = '!ruby/string'
+          maptag = '!ruby/string'.dup
           maptag << ":#{o.class}" unless o.class == ::String
 
           register o, @emitter.start_mapping(nil, maptag, false, Nodes::Mapping::BLOCK)
@@ -403,14 +350,18 @@ module Psych
 
       def visit_Array o
         if o.class == ::Array
-          register o, @emitter.start_sequence(nil, nil, true, Nodes::Sequence::BLOCK)
-          o.each { |c| accept c }
-          @emitter.end_sequence
+          visit_Enumerator o
         else
           visit_array_subclass o
         end
       end
 
+      def visit_Enumerator o
+        register o, @emitter.start_sequence(nil, nil, true, Nodes::Sequence::BLOCK)
+        o.each { |c| accept c }
+        @emitter.end_sequence
+      end
+
       def visit_NilClass o
         @emitter.scalar('', nil, 'tag:yaml.org,2002:null', true, false, Nodes::Scalar::ANY)
       end
@@ -436,15 +387,9 @@ module Psych
       end
 
       private
-      # FIXME: Remove the index and count checks in Psych 3.0
-      NULL         = "\x00"
-      BINARY_RANGE = "\x00-\x7F"
-      WS_RANGE     = "^ -~\t\r\n"
 
       def binary? string
-        (string.encoding == Encoding::ASCII_8BIT && !string.ascii_only?) ||
-          string.index(NULL) ||
-          string.count(BINARY_RANGE, WS_RANGE).fdiv(string.length) > 0.3
+        string.encoding == Encoding::ASCII_8BIT && !string.ascii_only?
       end
 
       def visit_array_subclass o
@@ -485,15 +430,6 @@ module Psych
           node = @emitter.start_mapping(nil, tag, false, Psych::Nodes::Mapping::BLOCK)
           register(o, node)
 
-          # Dump the elements
-          accept 'elements'
-          @emitter.start_mapping nil, nil, true, Nodes::Mapping::BLOCK
-          o.each do |k,v|
-            accept k
-            accept v
-          end
-          @emitter.end_mapping
-
           # Dump the ivars
           accept 'ivars'
           @emitter.start_mapping nil, nil, true, Nodes::Mapping::BLOCK
@@ -503,6 +439,15 @@ module Psych
           end
           @emitter.end_mapping
 
+          # Dump the elements
+          accept 'elements'
+          @emitter.start_mapping nil, nil, true, Nodes::Mapping::BLOCK
+          o.each do |k,v|
+            accept k
+            accept v
+          end
+          @emitter.end_mapping
+
           @emitter.end_mapping
         else
           tag = "!ruby/hash:#{o.class}"
@@ -519,6 +464,24 @@ module Psych
       def dump_list o
       end
 
+      def dump_exception o, msg
+        tag = ['!ruby/exception', o.class.name].join ':'
+
+        @emitter.start_mapping nil, tag, false, Nodes::Mapping::BLOCK
+
+        if msg
+          @emitter.scalar 'message', nil, nil, true, false, Nodes::Scalar::ANY
+          accept msg
+        end
+
+        @emitter.scalar 'backtrace', nil, nil, true, false, Nodes::Scalar::ANY
+        accept o.backtrace
+
+        dump_ivars o
+
+        @emitter.end_mapping
+      end
+
       def format_time time
         if time.utc?
           time.strftime("%Y-%m-%d %H:%M:%S.%9N Z")
@@ -527,24 +490,6 @@ module Psych
         end
       end
 
-      # FIXME: remove this method once "to_yaml_properties" is removed
-      def find_ivars target, is_primitive=false
-        begin
-          loc = target.method(:to_yaml_properties).source_location.first
-          unless loc.start_with?(Psych::DEPRECATED) || loc.end_with?('rubytypes.rb')
-            if $VERBOSE
-              warn "#{loc}: to_yaml_properties is deprecated, please implement \"encode_with(coder)\""
-            end
-            return target.to_yaml_properties
-          end
-        rescue
-          # public_method or source_location might be overridden,
-          # and it's OK to skip it since it's only to emit a warning.
-        end
-
-        is_primitive ? [] : target.instance_variables
-      end
-
       def register target, yaml_obj
         @st.register target, yaml_obj
         yaml_obj
@@ -566,9 +511,9 @@ module Psych
       def emit_coder c, o
         case c.type
         when :scalar
-          @emitter.scalar c.scalar, nil, c.tag, c.tag.nil?, false, Nodes::Scalar::ANY
+          @emitter.scalar c.scalar, nil, c.tag, c.tag.nil?, false, c.style
         when :seq
-          @emitter.start_sequence nil, c.tag, c.tag.nil?, Nodes::Sequence::BLOCK
+          @emitter.start_sequence nil, c.tag, c.tag.nil?, c.style
           c.seq.each do |thing|
             accept thing
           end
@@ -586,13 +531,57 @@ module Psych
       end
 
       def dump_ivars target
-        ivars = find_ivars target
-
-        ivars.each do |iv|
+        target.instance_variables.each do |iv|
           @emitter.scalar("#{iv.to_s.sub(/^@/, '')}", nil, nil, true, false, Nodes::Scalar::ANY)
           accept target.instance_variable_get(iv)
         end
       end
     end
+
+    class RestrictedYAMLTree < YAMLTree
+      DEFAULT_PERMITTED_CLASSES = {
+        TrueClass => true,
+        FalseClass => true,
+        NilClass => true,
+        Integer => true,
+        Float => true,
+        String => true,
+        Array => true,
+        Hash => true,
+      }.compare_by_identity.freeze
+
+      def initialize emitter, ss, options
+        super
+        @permitted_classes = DEFAULT_PERMITTED_CLASSES.dup
+        Array(options[:permitted_classes]).each do |klass|
+          @permitted_classes[klass] = true
+        end
+        @permitted_symbols = {}.compare_by_identity
+        Array(options[:permitted_symbols]).each do |symbol|
+          @permitted_symbols[symbol] = true
+        end
+        @aliases = options.fetch(:aliases, false)
+      end
+
+      def accept target
+        if !@aliases && @st.key?(target)
+          raise BadAlias, "Tried to dump an aliased object"
+        end
+
+        unless @permitted_classes[target.class]
+          raise DisallowedClass.new('dump', target.class.name || target.class.inspect)
+        end
+
+        super
+      end
+
+      def visit_Symbol sym
+        unless @permitted_symbols[sym]
+          raise DisallowedClass.new('dump', "Symbol(#{sym.inspect})")
+        end
+
+        super
+      end
+    end
   end
 end
