@@ -5,7 +5,7 @@
 # See LICENSE.txt for permissions.
 #++
 
-require 'rubygems/user_interaction'
+require_relative 'user_interaction'
 require 'rbconfig'
 
 ##
@@ -281,10 +281,10 @@ if you believe they were disclosed to a third party.
     check_credentials_permissions
 
     @api_keys = if File.exist? credentials_path
-                  load_file(credentials_path)
-                else
-                  @hash
-                end
+      load_file(credentials_path)
+    else
+      @hash
+    end
 
     if @api_keys.key? :rubygems_api_key
       @rubygems_api_key    = @api_keys[:rubygems_api_key]
@@ -320,7 +320,8 @@ if you believe they were disclosed to a third party.
     config = load_file(credentials_path).merge(host => api_key)
 
     dirname = File.dirname credentials_path
-    FileUtils.mkdir_p(dirname) unless File.exist? dirname
+    require 'fileutils'
+    FileUtils.mkdir_p(dirname)
 
     Gem.load_yaml
 
@@ -457,9 +458,8 @@ if you believe they were disclosed to a third party.
 
   # Writes out this config file, replacing its source.
   def write
-    unless File.exist?(File.dirname(config_file_name))
-      FileUtils.mkdir_p File.dirname(config_file_name)
-    end
+    require 'fileutils'
+    FileUtils.mkdir_p File.dirname(config_file_name)
 
     File.open config_file_name, 'w' do |io|
       io.write to_yaml
